# nucleus-api
BETA version of the nucleus text analytics API. Documentation: https://github.com/SumUpAnalytics/nucleus-sdk/tree/master/python/docs

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v0.1.4
- Package version: v0.1.4
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.5 and 3.6

## Installation & Usage
### pip install
Run pip from Python virtual environment
```sh
pip install nucleus_api --upgrade
```

Then import the package:
```python
import nucleus_api 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import nucleus_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import nucleus_api
from nucleus_api.rest import ApiException
from pprint import pprint

# Configure API key authorization: apikey
configuration = nucleus_api.Configuration()
configuration.api_key['x-api-key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-api-key'] = 'Bearer'

# create an instance of the API class
api_instance = nucleus_api.NucleusApi(nucleus_api.ApiClient(configuration))
dataset = 'dataset_example' # str | Dataset name.
target_author = 'target_author_example' # str | Name of the author to be analyzed.
time_period = 'time_period_example' # str | Time period selection
query = 'query_example' # str | Fulltext query, using mysql MATCH boolean query format. Subject covered by the author, on which to focus the analysis of connectivity. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\") (optional)
custom_stop_words = 'custom_stop_words_example' # str | List of words possibly used by the target author that are considered not information-bearing. (optional)
metadata_selection = 'metadata_selection_example' # str | json object of {\"metadata_field\":[\"selected_values\"]} (optional)
excluded_docs = 'excluded_docs_example' # str | List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\"  (optional)

try:
    api_response = api_instance.get_author_connectivity_api(dataset, target_author, time_period, query=query, custom_stop_words=custom_stop_words, metadata_selection=metadata_selection, excluded_docs=excluded_docs)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling NucleusApi->get_author_connectivity_api: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:5000*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*NucleusApi* | [**get_author_connectivity_api**](docs/NucleusApi.md#get_author_connectivity_api) | **GET** /topics/author_connectivity | 
*NucleusApi* | [**get_dataset_info**](docs/NucleusApi.md#get_dataset_info) | **GET** /datasets/dataset_info | 
*NucleusApi* | [**get_doc_display**](docs/NucleusApi.md#get_doc_display) | **GET** /documents/document_display | 
*NucleusApi* | [**get_doc_info**](docs/NucleusApi.md#get_doc_info) | **GET** /documents/document_info | 
*NucleusApi* | [**get_doc_recommend_api**](docs/NucleusApi.md#get_doc_recommend_api) | **GET** /documents/document_recommend | 
*NucleusApi* | [**get_doc_summary_api**](docs/NucleusApi.md#get_doc_summary_api) | **GET** /documents/document_summary | 
*NucleusApi* | [**get_job**](docs/NucleusApi.md#get_job) | **GET** /jobs | 
*NucleusApi* | [**get_list_datasets**](docs/NucleusApi.md#get_list_datasets) | **GET** /datasets | 
*NucleusApi* | [**get_topic_api**](docs/NucleusApi.md#get_topic_api) | **GET** /topics/topics | 
*NucleusApi* | [**get_topic_delta_api**](docs/NucleusApi.md#get_topic_delta_api) | **GET** /topics/topic_delta | 
*NucleusApi* | [**get_topic_summary_api**](docs/NucleusApi.md#get_topic_summary_api) | **GET** /topics/topic_summary | 
*NucleusApi* | [**get_user**](docs/NucleusApi.md#get_user) | **GET** /users | 
*NucleusApi* | [**post_append_json_to_dataset**](docs/NucleusApi.md#post_append_json_to_dataset) | **POST** /datasets/append_json_to_dataset | 
*NucleusApi* | [**post_delete_dataset**](docs/NucleusApi.md#post_delete_dataset) | **POST** /datasets/delete_dataset | 
*NucleusApi* | [**post_delete_document**](docs/NucleusApi.md#post_delete_document) | **POST** /datasets/delete_document | 
*NucleusApi* | [**post_example_job**](docs/NucleusApi.md#post_example_job) | **POST** /jobs/start_example_job | 
*NucleusApi* | [**post_legacy**](docs/NucleusApi.md#post_legacy) | **POST** /legacy | 
*NucleusApi* | [**post_topic_consensus_api**](docs/NucleusApi.md#post_topic_consensus_api) | **POST** /topics/topic_consensus | 
*NucleusApi* | [**post_topic_historical_analysis_api**](docs/NucleusApi.md#post_topic_historical_analysis_api) | **POST** /topics/topic_historical | 
*NucleusApi* | [**post_topic_sentiment_api**](docs/NucleusApi.md#post_topic_sentiment_api) | **POST** /topics/topic_sentiment | 
*NucleusApi* | [**post_upload_file**](docs/NucleusApi.md#post_upload_file) | **POST** /datasets/upload_file | 
*NucleusApi* | [**post_upload_url**](docs/NucleusApi.md#post_upload_url) | **POST** /datasets/import_file_from_url | 
*NucleusApi* | [**post_user**](docs/NucleusApi.md#post_user) | **POST** /users | 


## Documentation For Models

 - [ApiCall](docs/ApiCall.md)
 - [AppendJsonRespModel](docs/AppendJsonRespModel.md)
 - [Appendjsonparams](docs/Appendjsonparams.md)
 - [AuthorConnectRespModel](docs/AuthorConnectRespModel.md)
 - [DatasetInfoModel](docs/DatasetInfoModel.md)
 - [DatasetInfoRespModel](docs/DatasetInfoRespModel.md)
 - [DeleteDatasetRespModel](docs/DeleteDatasetRespModel.md)
 - [DeleteDocumentRespModel](docs/DeleteDocumentRespModel.md)
 - [Deletedatasetmodel](docs/Deletedatasetmodel.md)
 - [Deletedocumentmodel](docs/Deletedocumentmodel.md)
 - [DocAttributeModel](docs/DocAttributeModel.md)
 - [DocDisplayRespModel](docs/DocDisplayRespModel.md)
 - [DocInfoRespModel](docs/DocInfoRespModel.md)
 - [Document](docs/Document.md)
 - [DocumentRecommendRespModel](docs/DocumentRecommendRespModel.md)
 - [DocumentSummaryModel](docs/DocumentSummaryModel.md)
 - [DocumentSummaryRespModel](docs/DocumentSummaryRespModel.md)
 - [ExampleJobResponse](docs/ExampleJobResponse.md)
 - [JobRespModel](docs/JobRespModel.md)
 - [LegacyResponseModel](docs/LegacyResponseModel.md)
 - [ListDatasetsModel](docs/ListDatasetsModel.md)
 - [MetaData](docs/MetaData.md)
 - [NestedAuthorConnect](docs/NestedAuthorConnect.md)
 - [NestedAuthorConnect0](docs/NestedAuthorConnect0.md)
 - [NestedDocDispModel](docs/NestedDocDispModel.md)
 - [NestedDocInfoModel](docs/NestedDocInfoModel.md)
 - [NestedDocRecModel](docs/NestedDocRecModel.md)
 - [NestedDocumentSummaryModel](docs/NestedDocumentSummaryModel.md)
 - [NestedSummaryModel](docs/NestedSummaryModel.md)
 - [NestedTopicConsensusModel](docs/NestedTopicConsensusModel.md)
 - [NestedTopicDeltaModel](docs/NestedTopicDeltaModel.md)
 - [NestedTopicHistModel](docs/NestedTopicHistModel.md)
 - [NestedTopicSentimentModel](docs/NestedTopicSentimentModel.md)
 - [NestedTopicSummaryModel](docs/NestedTopicSummaryModel.md)
 - [PostUserRespModel](docs/PostUserRespModel.md)
 - [TopicConsensusRespModel](docs/TopicConsensusRespModel.md)
 - [TopicDeltaRespModel](docs/TopicDeltaRespModel.md)
 - [TopicHistoryRespModel](docs/TopicHistoryRespModel.md)
 - [TopicL1RespModel](docs/TopicL1RespModel.md)
 - [TopicRecommendModel](docs/TopicRecommendModel.md)
 - [TopicRespModel](docs/TopicRespModel.md)
 - [TopicSentimentRespModel](docs/TopicSentimentRespModel.md)
 - [TopicSummaryRespModel](docs/TopicSummaryRespModel.md)
 - [UploadFileRespModel](docs/UploadFileRespModel.md)
 - [UploadURLModel](docs/UploadURLModel.md)
 - [UploadUrlRespModel](docs/UploadUrlRespModel.md)
 - [User](docs/User.md)
 - [UserModel](docs/UserModel.md)


## Documentation For Authorization


## apikey

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header


## Author



